@@ -1,6 +1,6 @@
 /*
  *  Methods for LUKS-related key-management for cryptmount
- *  (C)Copyright 2005-2016, RW Penney
+ *  (C)Copyright 2005-2017, RW Penney
  */
 
 /*
@@ -389,6 +389,8 @@ static int kmluks_put_key(bound_tgtdefn_t *boundtgt,
                   boundtgt->tgt->ident);
         }
     } else {
+        int lukserr = 0;
+
         keyslot = (luksor != NULL ? luksor->keyslot : 0);
 
         if (crypt_load(luks_ctxt, NULL, NULL) < 0) {
@@ -397,11 +399,10 @@ static int kmluks_put_key(bound_tgtdefn_t *boundtgt,
         }
 
         printf(_("Setting password on LUKS keyslot-%u\n"), keyslot);
-        if (kmluks_change_slot_passwd(luks_ctxt, keyslot,
-                                      key, keylen, passwd) < 0) {
-            char errmsg[256];
-            crypt_last_error(luks_ctxt, errmsg, sizeof(errmsg));
-            fprintf(stderr, "LUKS error: %s\n", errmsg);
+        lukserr = kmluks_change_slot_passwd(luks_ctxt, keyslot,
+                                            key, keylen, passwd);
+        if (lukserr < 0) {
+            fprintf(stderr, "LUKS error code %d\n", -lukserr);
             eflag = ERR_BADENCRYPT;
             goto bail_out;
         }
@@ -491,5 +492,5 @@ keymanager_t *kmluks_gethandle()
 /**  @} */
 
 /*
- *  (C)Copyright 2005-2016, RW Penney
+ *  (C)Copyright 2005-2017, RW Penney
  */
