@@ -1,6 +1,6 @@
 /*
  *  Device-mapper utilities for cryptmount
- *  (C)Copyright 2005-2016, RW Penney
+ *  (C)Copyright 2005-2017, RW Penney
  */
 
 /*
@@ -28,6 +28,9 @@
 #include <string.h>
 #include <unistd.h>
 #include <sys/stat.h>
+#if HAVE_SYS_SYSMACROS_H
+#  include <sys/sysmacros.h>
+#endif
 #include <sys/types.h>
 #if HAVE_NANOSLEEP
 #  include <time.h>
@@ -374,5 +377,5 @@ int udev_active_dir(const char *path, time_t starttime, double timeout)
 }
 
 /*
- *  (C)Copyright 2005-2016, RW Penney
+ *  (C)Copyright 2005-2017, RW Penney
  */
