@@ -1,6 +1,6 @@
 /*
  *  Filesystem-related utilities for cryptmount
- *  (C)Copyright 2005-2016, RW Penney
+ *  (C)Copyright 2005-2017, RW Penney
  */
 
 /*
@@ -34,6 +34,9 @@
 #include <sys/mount.h>
 #include <sys/stat.h>
 #include <sys/statvfs.h>
+#if HAVE_SYS_SYSMACROS_H
+#  include <sys/sysmacros.h>
+#endif
 #include <sys/types.h>
 #include <sys/wait.h>
 
@@ -708,5 +711,5 @@ int fs_test_entropy()
 #endif  /* TESTING */
 
 /*
- *  (C)Copyright 2005-2016, RW Penney
+ *  (C)Copyright 2005-2017, RW Penney
  */
