@@ -1,6 +1,6 @@
 /*
  *  Loopback-device utilities for cryptmount
- *  (C)Copyright 2005-2016, RW Penney
+ *  (C)Copyright 2005-2017, RW Penney
  */
 
 /*
@@ -32,6 +32,9 @@
 #include <unistd.h>
 #include <sys/ioctl.h>
 #include <sys/stat.h>
+#if HAVE_SYS_SYSMACROS_H
+#  include <sys/sysmacros.h>
+#endif
 #include <sys/types.h>
 
 #ifdef HAVE_LINUX_LOOP_H
@@ -298,5 +301,5 @@ int unblockify_file(const char **devname, int isloop)
 }
 
 /*
- *  (C)Copyright 2005-2016, RW Penney
+ *  (C)Copyright 2005-2017, RW Penney
  */
