@@ -1,6 +1,6 @@
 /*
  *  Miscellaneous utility functions for cryptmount
- *  (C)Copyright 2005-2016, RW Penney
+ *  (C)Copyright 2005-2017, RW Penney
  */
 
 /*
@@ -29,6 +29,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#if HAVE_SYS_SYSMACROS_H
+#  include <sys/sysmacros.h>
+#endif
 #include <sys/times.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -1032,5 +1035,5 @@ int ut_pwfort()
 #endif  /* TESTING */
 
 /*
- *  (C)Copyright 2005-2016, RW Penney
+ *  (C)Copyright 2005-2017, RW Penney
  */
